from aws_managers.athena.athena_frame import AthenaFrame
from aws_managers.athena.athena_query_generator import AthenaQueryGenerator
